`Home <index.rst>`_

Special support for Turtle programs
===================================

When developing programs with ``turtle`` module, Thonny offers you following support:

* You can leave out ``mainloop``, ``done`` or ``exitonclick`` calls from your script (Thonny will take care of keeping the Turtle window responsive). This allows you to create part of your drawing with script and continue adding features via the shell. You can also create whole drawing via the shell.
* You can `dock the Turtle window <dock.rst>`_, so that it's visible while you are working on your script. 